Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(69)

Unified Diff: experimental/SkV8Example/Path2D.h

Issue 177963005: Rename Path to Path2D (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « experimental/SkV8Example/Path.cpp ('k') | experimental/SkV8Example/Path2D.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: experimental/SkV8Example/Path2D.h
diff --git a/experimental/SkV8Example/Path.h b/experimental/SkV8Example/Path2D.h
similarity index 76%
rename from experimental/SkV8Example/Path.h
rename to experimental/SkV8Example/Path2D.h
index 370f168a2e8bd9707b4a3b78fccbc54cdd5008bf..93c1299c61e29c42163205c18651945ba854e8b2 100644
--- a/experimental/SkV8Example/Path.h
+++ b/experimental/SkV8Example/Path2D.h
@@ -7,8 +7,8 @@
*
*/
-#ifndef SkV8Example_Path_DEFINED
-#define SkV8Example_Path_DEFINED
+#ifndef SkV8Example_Path2D_DEFINED
+#define SkV8Example_Path2D_DEFINED
#include <v8.h>
@@ -17,20 +17,20 @@
class Global;
-class Path : SkNoncopyable {
+class Path2D : SkNoncopyable {
public:
- Path() : fSkPath() {}
- virtual ~Path() {}
+ Path2D() : fSkPath() {}
+ virtual ~Path2D() {}
const SkPath& getSkPath() { return fSkPath; }
// The JS Path constuctor implementation.
static void ConstructPath(const v8::FunctionCallbackInfo<v8::Value>& args);
// Add the Path JS constructor to the global context.
static void AddToGlobal(Global* global);
- // Path JS methods.
+ // Path2D JS methods.
static void ClosePath(const v8::FunctionCallbackInfo<v8::Value>& args);
static void MoveTo(const v8::FunctionCallbackInfo<v8::Value>& args);
static void LineTo(const v8::FunctionCallbackInfo<v8::Value>& args);
@@ -44,7 +44,7 @@ public:
private:
SkPath fSkPath;
- static Path* Unwrap(const v8::FunctionCallbackInfo<v8::Value>& args);
+ static Path2D* Unwrap(const v8::FunctionCallbackInfo<v8::Value>& args);
static Global* gGlobal;
};
« no previous file with comments | « experimental/SkV8Example/Path.cpp ('k') | experimental/SkV8Example/Path2D.cpp » ('j') | no next file with comments »
@@ -17,20 +17,20 @@
const SkPath& getSkPath() { return fSkPath; }
- // The JS Path constuctor implementation.
+ // The JS Path2D constuctor implementation.
static void ConstructPath(const v8::FunctionCallbackInfo<v8::Value>& args);
@@ -17,20 +17,20 @@
static void ConstructPath(const v8::FunctionCallbackInfo<v8::Value>& args);
- // Add the Path JS constructor to the global context.
+ // Add the Path2D JS constructor to the global context.
static void AddToGlobal(Global* global);

Powered by Google App Engine
This is Rietveld 408576698